/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <folly/dynamic.h>
#include <folly/portability/GTest.h>

TEST(dynamic, objectCtor) {
  folly::dynamic o1 = folly::dynamic::object;
  folly::dynamic o2 =
      folly::dynamic::object("key", "value")(1, 2)(nullptr, nullptr);

  ASSERT_TRUE(o1.isObject());
  ASSERT_TRUE(o2.isObject());
  ASSERT_EQ(o1.size(), 0);
  ASSERT_EQ(o2.size(), 3);

  EXPECT_EQ(o2["key"], "value");
  EXPECT_EQ(o2[1], 2);
  EXPECT_EQ(o2[nullptr], nullptr);
}
